PrefixExpression<I, O> class abstract

Inheritance
Implementers
Available extensions

Constructors

PrefixExpression(Expression<I> expression)

Properties

expression Expression<I>
finalinherited
hashCode int
The hash code for this object.
no setterinherited
isOptional bool
getter/setter pairinherited
kind ExpressionKind
no setterinherited
opt OptionalExpression<E>

Available on Expression<E>, provided by the ExpressionExt extension

no setter
plus OneOrMoreExpression<E>

Available on Expression<E>, provided by the ExpressionExt extension

no setter
prefix String
no setter
rule ProductionRule?
getter/setter pairinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
star ZeroOrMoreExpression<E>

Available on Expression<E>, provided by the ExpressionExt extension

no setter
startCharacters → SparseBoolList
finalinherited
startTerminals Set<TerminalRule>
finalinherited

Methods

accept<R>(ExpressionVisitor<R> visitor) → R
inherited
locate<O>(O action(String source, int start, int end, E result)) LocationalTransformerExpression<E, O>

Available on Expression<E>, provided by the ExpressionExt extension

map<O>(O f(O)) TransformerExpression<O, O>
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override
visitChildren<R>(ExpressionVisitor<R> visitor) → void
inherited

Operators

operator <<(Expression expression) Sequence2Expression<E, dynamic>

Available on Expression<E>, provided by the ExpressionExt extension

operator ==(Object other) bool
The equality operator.
inherited