Sequence6Expression<E1, E2, E3, E4, E5, E6> class

Inheritance

Constructors

Sequence6Expression(Expression<E1> e1, Expression<E2> e2, Expression<E3> e3, Expression<E4> e4, Expression<E5> e5, Expression<E6> e6)

Properties

e1 → Expression<E1>
final
e2 → Expression<E2>
final
e3 → Expression<E3>
final
e4 → Expression<E4>
final
e5 → Expression<E5>
final
e6 → Expression<E6>
final
expressions → List<Expression>
finalinherited
hashCode → int
The hash code for this object.
no setterinherited
isOptional ↔ bool
getter/setter pairinherited
kind → ExpressionKind
no setterinherited
rule ↔ ProductionRule?
getter/setter pairinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
startCharacters → SparseBoolList
finalinherited
startTerminals → Set<TerminalRule>
finalinherited

Methods

accept<R>(ExpressionVisitor<R> visitor) → R
override
map<O>(O f(Tuple6<E1, E2, E3, E4, E5, E6>)) → TransformerExpression<Tuple6<E1, E2, E3, E4, E5, E6>, O>
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited
visitChildren<R>(ExpressionVisitor<R> visitor) → void
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited