SequenceFirstLastResultExpression<E1, E2> class

Inheritance

Constructors

SequenceFirstLastResultExpression(Expression<E1> first, List<Expression> middle, Expression<E2> last)

Properties

expressions → List<Expression>
finalinherited
first → Expression<E1>
final
hashCode → int
The hash code for this object.
no setterinherited
isOptional ↔ bool
getter/setter pairinherited
kind → ExpressionKind
no setterinherited
last → Expression<E2>
final
middle → List<Expression>
final
rule ↔ ProductionRule?
getter/setter pairinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
startCharacters → SparseBoolList
finalinherited
startTerminals → Set<TerminalRule>
finalinherited

Methods

accept<R>(ExpressionVisitor<R> visitor) → R
override
map<O>(O f(Tuple2<E1, E2>)) → TransformerExpression<Tuple2<E1, E2>, O>
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited
visitChildren<R>(ExpressionVisitor<R> visitor) → void
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited