Expression<E> class
abstract
- Implementers
- Available extensions
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- isOptional ↔ bool
-
getter/setter pair
- kind → ExpressionKind
-
no setter
-
opt
→ OptionalExpression<
E> -
Available on Expression<
E> , provided by the ExpressionExt extensionno setter -
plus
→ OneOrMoreExpression<
E> -
Available on Expression<
E> , provided by the ExpressionExt extensionno setter - rule ↔ ProductionRule?
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
star
→ ZeroOrMoreExpression<
E> -
Available on Expression<
E> , provided by the ExpressionExt extensionno setter - startCharacters → SparseBoolList
-
final
-
startTerminals
→ Set<
TerminalRule> -
final
Methods
-
accept<
R> (ExpressionVisitor< R> visitor) → R -
locate<
O> (O action(String source, int start, int end, E result)) → LocationalTransformerExpression< E, O> -
Available on Expression<
E> , provided by the ExpressionExt extension -
map<
O> (O f(E)) → TransformerExpression< E, O> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
visitChildren<
R> (ExpressionVisitor< R> visitor) → void
Operators
-
operator <<(
Expression expression) → Sequence2Expression< E, dynamic> -
Available on Expression<
E> , provided by the ExpressionExt extension -
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
- allCharacters → SparseBoolList
-
final
- allCharactersWithEof → SparseBoolList
-
final
Static Methods
-
quote(
Expression expression, {String prefix = '', String suffix = ''}) → String
Constants
- eof → const int
- maxUnicode → const int